==> pythagoras-0.10.56.tar.gz: pythagoras-0.10.56/README.md <==
# Pythagoras

Planet-scale distributed computing in Python.

## What is it?

`Pythagoras` is an easy-to-use framework for cost-efficient
massive algorithm parallelization in Python. It simplifies and accelerates 
data science, machine learning, and AI workflows.

Pythagoras offers:

* seamless parallel execution of Python code, locally or 
in diverse distributed environments of any scale;
* ubiquitous caching for intermediate program states, 
with intelligent data and code change tracking;
* extremely simple and budget-friendly orchestration backend.

## Usage

* `Introduction to Pythagoras` notebook:
https://colab.research.google.com/drive/1tSJkpHl49Y9ZrYskkdoH2ti3_VZ5_6cj

## How to get it?

The source code is hosted on GitHub at: https://github.com/vladlpavlov/pythagoras

Installers for the latest released version are available 
at the Python package index at: https://pypi.org/project/pythagoras

    pip install pythagoras

## Dependencies

* [persidict](https://pypi.org/project/persidict)
* [jsonpickle](https://jsonpickle.github.io)
* [joblib](https://joblib.readthedocs.io)
* [lz4](https://python-lz4.readthedocs.io)
* [pandas](https://pandas.pydata.org)
* [numpy](https://numpy.org)
* [psutil](https://psutil.readthedocs.io)
* [boto3](https://boto3.readthedocs.io)
* [pytest](https://pytest.org)
* [moto](http://getmoto.org)
* [boto3](https://boto3.readthedocs.io)
* [scipy](https://www.scipy.org)
* [jsonpickle](https://jsonpickle.github.io)
* [scikit-learn](https://scikit-learn.org)
* [autopep8](https://pypi.org/project/autopep8)
* [pytorch](https://pytorch.org)
* [tensorflow](https://www.tensorflow.org)
* [keras](https://keras.io)

## Key Contacts

* [Vlad (Volodymyr) Pavlov](https://www.linkedin.com/in/vlpavlov/)

## About The Name

Pythagoras of Samos was a famous ancient Greek thinker and scientist 
who was the first man to call himself a philosopher ("lover of wisdom"). 
He is most recognised for his many mathematical findings, 
including the Pythagorean theorem. 

Not everyone knows that in antiquity, Pythagoras was also credited with 
major astronomical discoveries, such as sphericity of the Earth 
and the identity of the morning and evening stars as the planet Venus.

==> pythagoras-0.16.0.tar.gz: pythagoras-0.16.0/README.md <==
# Pythagoras

Planet-scale distributed computing in Python.

## What is it?

`Pythagoras` is an easy-to-use framework for cost-efficient
massive algorithm parallelization in Python. It simplifies and accelerates 
data science, machine learning, and AI workflows.

Pythagoras offers:

* seamless parallel execution of Python code, locally or 
in diverse distributed environments of any scale;
* ubiquitous caching for intermediate program states, 
with intelligent data and code change tracking;
* simple and budget-friendly orchestration backend.

## Usage

* `Introduction to Pythagoras` notebook:
https://colab.research.google.com/drive/1tSJkpHl49Y9ZrYskkdoH2ti3_VZ5_6cj

## How to get it?

The source code is hosted on GitHub at: https://github.com/pythagoras-dev/pythagoras

Installers for the latest released version are available 
at the Python package index at: https://pypi.org/project/pythagoras

    pip install pythagoras

## Dependencies

* [persidict](https://pypi.org/project/persidict)
* [jsonpickle](https://jsonpickle.github.io)
* [joblib](https://joblib.readthedocs.io)
* [lz4](https://python-lz4.readthedocs.io)
* [pandas](https://pandas.pydata.org)
* [numpy](https://numpy.org)
* [psutil](https://psutil.readthedocs.io)
* [boto3](https://boto3.readthedocs.io)
* [pytest](https://pytest.org)
* [moto](http://getmoto.org)
* [boto3](https://boto3.readthedocs.io)
* [scipy](https://www.scipy.org)
* [jsonpickle](https://jsonpickle.github.io)
* [scikit-learn](https://scikit-learn.org)
* [autopep8](https://pypi.org/project/autopep8)
* [pytorch](https://pytorch.org)
* [tensorflow](https://www.tensorflow.org)
* [keras](https://keras.io)
* [deepdiff](https://zepworks.com/deepdiff/current/)

## Key Contacts

* [Vlad (Volodymyr) Pavlov](https://www.linkedin.com/in/vlpavlov/)

## About The Name

Pythagoras of Samos was a famous ancient Greek thinker and scientist 
who was the first man to call himself a philosopher ("lover of wisdom"). 
He is most recognised for his many mathematical findings, 
including the Pythagorean theorem. 

Not everyone knows that in antiquity, Pythagoras was also credited with 
major astronomical discoveries, such as sphericity of the Earth 
and the identity of the morning and evening stars as the planet Venus.
